SystemOrganization addCategory: #'Seaside-Tests-Functional'!

WAComponent subclass: #WAAllTests
	instanceVariableNames: 'classes current'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAAllTests commentStamp: 'sd 11/28/2004 14:42' prior: 0!
If you want to see these examples:

/seaside/config app:
- add a new application named "tests"
- choose WAAllTests as the root component
!

!WAAllTests class methodsFor: 'testing' stamp: 'mb 1/31/2006 11:07'!
canBeRoot
	^ true! !

!WAAllTests class methodsFor: 'accessing' stamp: 'lr 2/25/2007 23:15'!
description
	^ 'Functional Seaside Test Suite'! !

!WAAllTests class methodsFor: 'initialization' stamp: 'pmm 7/31/2007 07:17'!
initialize
	(self registerAsApplication: 'tests/alltests')
		preferenceAt: #sessionClass put: WAExpirySession! !

!WAAllTests methodsFor: 'actions' stamp: 'lr 8/31/2008 15:29'!
activate: aClass
	current contents: aClass new.
	(current contents respondsTo: #parent:)
		ifTrue: [ current contents parent: self ]! !

!WAAllTests methodsFor: 'accessing' stamp: 'lr 5/31/2008 11:15'!
children
	^ Array with: current contents! !

!WAAllTests methodsFor: 'initialize-release' stamp: 'lr 5/31/2008 10:47'!
initialize
	super initialize.
	self initializeTests! !

!WAAllTests methodsFor: 'initialize-release' stamp: 'lr 9/12/2008 18:12'!
initializeTests
	classes := SortedCollection sortBlock: [ :a :b | a name < b name ].
	WAFunctionalTest allSubclassesDo: [ :each | classes add: each ].
	WAFunctionalTaskTest allSubclassesDo: [ :each | classes add: each ].
	current := WAValueHolder with: classes first new! !

!WAAllTests methodsFor: 'actions' stamp: 'pmm 9/1/2008 23:22'!
next
	| nextIndex |
	nextIndex := self selectionIndex \\ classes size + 1.
	self activate: (classes at: nextIndex)
	! !

!WAAllTests methodsFor: 'actions' stamp: 'pmm 9/1/2008 23:26'!
previous
	| nextIndex |
	nextIndex := (self selectionIndex + classes size - 2 \\ classes size) + 1.
	self activate: (classes at: nextIndex)! !

!WAAllTests methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:42'!
renderContentOn: html
	html heading: 'Functional Seaside Test Suite'.
	html form: [
		html paragraph: [
			html anchor
				callback: [ self previous ];
				with: [ html html: '&larr;' ].
			html select
				list: classes;
				beSubmitOnChange;
				labels: [ :value | value name ];
				selected: self selected;
				callback: [ :value | self activate: value ].
			html anchor
				callback: [ self next ];
				with: [ html html: '&rarr;' ].
			html text: ' '; submitButton: 'Restart' ] ].
	html horizontalRule.
	html render: current contents! !

!WAAllTests methodsFor: 'accessing' stamp: 'pmm 9/1/2008 22:38'!
selected
	^current contents class! !

!WAAllTests methodsFor: 'private' stamp: 'pmm 9/1/2008 23:21'!
selectionIndex
	^classes indexOf: self selected! !

!WAAllTests methodsFor: 'accessing' stamp: 'lr 5/31/2008 11:15'!
states
	^ Array with: current! !

WAComponent subclass: #WAFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

WAFunctionalTest subclass: #WABatchFunctionalTest
	instanceVariableNames: 'batcher'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WABatchFunctionalTest methodsFor: 'accessing' stamp: 'avi 12/18/2004 18:33'!
children
	^ Array with: batcher! !

!WABatchFunctionalTest methodsFor: 'initialization' stamp: 'pmm 9/12/2006 18:10'!
initialize
	super initialize.
	batcher := WAAlphabeticBatchedList new items: Collection allSubclasses! !

!WABatchFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderContentOn: html
	html render: batcher.
	html unorderedList
		list: batcher batch! !

WAFunctionalTest subclass: #WAButtonFunctionalTest
	instanceVariableNames: 'input'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAButtonFunctionalTest methodsFor: 'initialize-release' stamp: 'pmm 7/28/2007 08:43'!
initialize
	super initialize.
	self input: 'a text'! !

!WAButtonFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/28/2007 08:37'!
input
	^input! !

!WAButtonFunctionalTest methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
input: aString
	input := aString! !

!WAButtonFunctionalTest methodsFor: 'rendering' stamp: 'pmm 7/28/2007 08:48'!
renderContentOn: html
	html form: [
		html div: [
			self renderInputOn: html.
			self renderSubmitOn: html.
			self renderResetOn: html.
			self renderPushOn: html ] ]! !

!WAButtonFunctionalTest methodsFor: 'rendering' stamp: 'pmm 7/28/2007 08:46'!
renderInputOn: html
	html table: [
		html tableRow: [
			html tableHeading: 'Value:'.
			html tableData: self input ].
		html tableRow: [
			html tableHeading: 'Input:'.
			html tableData: [
				html textInput
					on: #input of: self ] ] ]! !

!WAButtonFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderPushOn: html
	html heading level2 with: 'Push'.
	html paragraph: 'Clicking the button should not do anything.'.
	html button bePush; with: 'Push'! !

!WAButtonFunctionalTest methodsFor: 'rendering' stamp: 'lr 2/28/2008 11:54'!
renderResetOn: html
	html heading level2 with: 'Reset'.
	html paragraph: 'Clicking the button should not submit the form and reset the value in "Input"'.
	html button beReset; with: 'Reset'! !

!WAButtonFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderSubmitOn: html
	html heading level2 with: 'Submit'.
	html paragraph: 'Clicking the button should submit the form and update the value in "Value:" with the value in "Input"'.
	html button with: 'Submit'! !

WAFunctionalTest subclass: #WACallbackFunctionalTest
	instanceVariableNames: 'transcript'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WACallbackFunctionalTest methodsFor: 'accessing' stamp: 'lr 2/28/2008 11:42'!
append: aString
	transcript nextPutAll: aString; cr! !

!WACallbackFunctionalTest methodsFor: 'initialization' stamp: 'lr 2/28/2008 11:42'!
initialize
	super initialize.
	transcript := String new writeStream! !

!WACallbackFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 10:02'!
renderContentOn: html 
	html paragraph: 'Depending on the way the form is submitted the following actions should be triggered and logged:'.
	html orderedList list: #( 
		'Default: Text, Default'
		'Before: Text'
		'Before Submit: Text, Before Submit'
		'Before Cancel: Before Cancel'
		'After: Text'
		'After Submit: Text, After Submit'
		'After Cancel: After Cancel'
	).
	html form
		defaultAction: [ self append: 'Default' ] ;
		with: [
			html div: [
				"div for validation"
				html submitButton
					text: 'Before'.
				html submitButton
					callback:  [ self append: 'Before Submit' ];
					text: 'Before Submit'.
				html cancelButton
					callback:  [ self append: 'Before Cancel' ];
					text: 'Before Cancel'.
				html break.
				html textInput
					value: 'Some Text';
					callback: [ :value | self append: 'Text: ' , value ].
				html break.
				html submitButton
					text: 'After'.
				html submitButton
					callback:  [ self append: 'After Submit' ];
					text: 'After Submit'.
				html cancelButton
					callback:  [ self append: 'After Cancel' ];
					text: 'After Cancel' ] ].
	html preformatted: transcript contents.
	transcript reset! !

WAFunctionalTest subclass: #WACanvasTableFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WACanvasTableFunctionalTest methodsFor: 'samples' stamp: 'lr 10/28/2007 14:42'!
entities
	^#(
		('non-breaking space' ('&nbsp;' '&#160;' '&#xA0;'))
		('ampersand' ('&amp;' '&#38;' '&#x26;'))
		('less than sign' ('&lt;' '&#60;' '&#x3C;'))
		('greater than sign' ('&gt;' '&#62;' '&#x3E;'))
		('euro sign' ('&euro;' '&#8364;' '&#x20AC;'))
	)! !

!WACanvasTableFunctionalTest methodsFor: 'samples' stamp: 'lr 10/28/2007 14:42'!
exchangeRates
	^#(
		('EUR' 1.70)
		('USD' 1.30)
		('DKK' 23.36)
		('SEK' 19.32)
	)! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/16/2007 17:11'!
renderContentOn: html
	html div
		class: 'wacanvastabletest';
		with: [
			self renderEntityTableOn: html.
			self renderCurrencyTableOn: html ]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderCurrencyTableBodyOn: html
	html tableBody title: 'Table body';
		with: [
			self exchangeRates do: [:each |
				html tableRow: [
					html tableHeading: each first.
					html tableData align: 'char'; character: $.;
						with: each second]]]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderCurrencyTableHeadOn: html
	html tableHead title: 'Table header';
		with: [
			html tableRow: [
				html tableHeading: 'Currency'.
				html tableHeading: 'Rate']]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderCurrencyTableOn: html
	html table
 		summary: 'This table shows exchange rates against the Swiss Franc';
		with: [
			html tableCaption: 'Currencies against Swiss Franc (CHF)'.
			html tableColumnGroup.
			html tableColumnGroup width: '100px'; align: 'char'; character: $..
			self renderCurrencyTableHeadOn: html.
			self renderCurrencyTableBodyOn: html]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderEntityTableBodyOn: html
	html tableBody: [
		self entities do: [:eachEntity |
			html tableRow: [
				html tableData scope: 'row';
					with: eachEntity first.
				eachEntity second do: [ :each |
					html tableData: each ].
				eachEntity second do: [ :each |
					html tableData align: 'center';
						with: [ html html: each ] ] ] ] ]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderEntityTableColumnGroupsOn: html
	html tableColumnGroup.
	html tableColumnGroup span: 3.
	html tableColumnGroup span: 3; align: 'center'! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderEntityTableFootOn: html
	html tableFoot: [
		html tableRow: [
			html tableData align: 'center'; colSpan: 7;
				with: '5 entities shown']]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderEntityTableHeadOn: html
	html tableHead: [
		html tableRow: [
			#('Character' 'Entity' 'Decimal' 'Hex') do: [:each |
				html tableHeading scope: 'col'; rowSpan: 2;
					with: each].
			html tableHeading scope: 'colgroup'; colSpan: 3;
				with: 'Rendering in Your Browser'
		].
		html tableRow: [
			#('Entity' 'Decimal' 'Hex') do: [:each |
				html tableHeading scope: 'col'; with: each]
		].
	]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderEntityTableOn: html
	html table
 		summary: 'This table gives the character entity reference,
                decimal character reference, and hexadecimal character
                reference for 8-bit Latin-1 characters, as well as the
                rendering of each in your browser.';
		with: [
			html tableCaption: 'HTML 4.0 entities'.
			self renderEntityTableColumnGroupsOn: html.
			self renderEntityTableHeadOn: html.
			self renderEntityTableFootOn: html.
			self renderEntityTableBodyOn: html]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/16/2007 17:23'!
style
	^'
.wacanvastabletest table {
	border-collapse: collapse;
	border:1px solid black;
	margin:0px auto; /* center */
}

.wacanvastabletest caption {
	margin:0px auto; /* center */
}
.wacanvastabletest caption {
	font-weight: bold;
	padding: 0.5em 0 1em 0;
}
.wacanvastabletest td, .wacanvastabletest th {
	padding: 3px;
	border:1px solid black;
}
'! !

WAFunctionalTest subclass: #WAClosureFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAClosureFunctionalTest methodsFor: 'actions' stamp: 'lr 2/28/2008 09:25'!
ensure
	[ self go ] ensure: [ self inform: 'ensure' ]! !

!WAClosureFunctionalTest methodsFor: 'actions' stamp: 'lr 2/28/2008 09:28'!
go
	(1 to: 3) do: [ :index | self inform: index ]! !

!WAClosureFunctionalTest methodsFor: 'rendering' stamp: 'lr 2/28/2008 11:56'!
renderContentOn: html
	html paragraph: 'The following two anchors should trigger a 3 step flow. Backtracking and spawning of windows should properly work.'.
	html paragraph: [
		html anchor
			callback: [ self go ];
			with: 'Go'.
		html break.
		html anchor
			callback: [ self ensure ];
			with: 'Go with ensure' ]! !

WAFunctionalTest subclass: #WAContextFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAContextFunctionalTest methodsFor: 'rendering' stamp: 'lr 4/9/2008 10:44'!
renderContentOn: html
	self renderExplanationOn: html.
	html table: [
		self renderLabel: 'Server:' value:  self requestContext server on: html.
		self renderLabel: 'Session:' value:  self requestContext session on: html.
		self renderLabel: 'Application:' value:  self requestContext application on: html.
		self renderLabel: 'Request:' value:  self requestContext request on: html.
		self renderLabel: 'Response:' value:  self requestContext response on: html.
		self renderRequestHandlersOn: html.
		self renderPropertiesOn: html ]! !

!WAContextFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/30/2008 16:38'!
renderExplanationOn: html

	html paragraph: 'The purpose of this test is to make sure WAContext and WACurrentContext work correctly. For each label you should see the print string of one or several matching objects. For the ''Request Handlers'' the first object should be a WASession or subclass, the second a WAApplication and then one or several WADispatchers matching the path.'! !

!WAContextFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/30/2008 16:15'!
renderLabel: aString value: anObject on: html
	html tableRow: [
		html tableHeading: aString.
		html tableData: anObject ]! !

!WAContextFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:45'!
renderPropertiesOn: html
	html tableRow: [
		html tableHeading: 'Properties:'.
		html tableData: [
			| properties |
			properties := self requestContext properties.
			properties isEmpty ifFalse: [
				html definitionList: [
					properties keysAndValuesDo: [ :key :value |
						html definitionTerm: key.
						html definitionData: value ] ] ] ] ]! !

!WAContextFunctionalTest methodsFor: 'rendering' stamp: 'lr 4/9/2008 10:43'!
renderRequestHandlersOn: html 
	html tableRow: [
		html tableHeading: 'Request Handlers:'.
		html tableData: [ 
			html orderedList list: self requestContext handlers ] ]! !

WAFunctionalTest subclass: #WACookieFunctionalTest
	instanceVariableNames: 'key value path firstKey firstValue firstPath secondKey secondValue secondPath'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WACookieFunctionalTest methodsFor: 'actions' stamp: 'jf 9/29/2008 09:45'!
addBoth
	| response |
	self session respond: [ :url |
		response := self session redirectResponseFor: url.
		response addCookie: self firstCookie.
		response addCookie: self secondCookie.
		response ].
	
	self firstKey: nil.
	self firstValue: nil.
	self firstPath: self application baseUrl pathString.
	
	self secondKey: nil.
	self secondValue: nil.
	self secondPath: self application baseUrl pathString! !

!WACookieFunctionalTest methodsFor: 'actions' stamp: 'jf 9/29/2008 09:45'!
addFirst
	| response |
	self session respond: [ :url |
		response := self session redirectResponseFor: url.
		response addCookie: self firstCookie.
		response ].
	
	self firstKey: nil.
	self secondKey: nil.
	self firstPath: self application baseUrl pathString! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'lr 4/9/2008 10:43'!
cookies
	^ self requestContext request cookies! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'lr 4/9/2008 10:43'!
firstCookie
	^self requestContext newCookie
		key: self firstKey;
		value: self firstValue;
		path: self firstPath;
		yourself! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:11'!
firstKey
	^ firstKey! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:30'!
firstKey: aString
	firstKey := aString! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:11'!
firstPath
	^ firstPath! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:30'!
firstPath: aString
	firstPath := aString! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:11'!
firstValue
	^ firstValue! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:30'!
firstValue: aString
	firstValue := aString! !

!WACookieFunctionalTest methodsFor: 'initialize-release' stamp: 'jf 9/29/2008 09:45'!
initialize
	super initialize.
	self firstPath: self application baseUrl pathString.
	self secondPath: self application baseUrl pathString.! !

!WACookieFunctionalTest methodsFor: 'actions' stamp: 'pmm 4/5/2008 15:45'!
remove: aCookie
	
	self session respond: [ :url |
		| response |
		response := self session redirectResponseFor: url.
		response deleteCookie: aCookie.
		response ]! !

!WACookieFunctionalTest methodsFor: 'rendering-explanation' stamp: 'pmm 4/5/2008 16:52'!
renderCombiningOn: html
	html listItem: 'Setting both cookies should work in Kom and is broken in Swazoo.'! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 4/5/2008 14:05'!
renderContentOn: html
	self renderExplanationOn: html.

	html form: [
		html table: [
			self renderHeadingsOn: html.
			self renderCookiesOn: html.
			self renderInputOn: html ] ]! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/22/2008 20:20'!
renderCookiesOn: html
	self cookies do: [ :each |
		html tableRow: [
			html tableData: each key.
			html tableData: each value.
			html tableData: each path.
			html tableData: each domain.
			html tableData: each ports.
			html tableData: [
				html submitButton
					callback: [ self remove: each ];
					text: 'remove' ] ] ]! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 4/5/2008 14:08'!
renderExplanationOn: html
	html unorderedList: [
		self renderFirefoxOn: html.
		self renderSafariOn: html.
		self renderOperaOn: html.
		self renderRemoveOn: html ]! !

!WACookieFunctionalTest methodsFor: 'rendering-explanation' stamp: 'pmm 4/5/2008 14:08'!
renderFirefoxOn: html
	html listItem: 'On Firefox the path is not supposed to work. But if you look under Settings -> Cookies the cookie should be saved with the correct path.'! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/22/2008 20:18'!
renderHeadingsOn: html
	html tableRow: [
		html tableHeading: 'Key'.
		html tableHeading: 'Value'.
		html tableHeading: 'Path'.
		html tableHeading: 'Domain'.
		html tableHeading: 'Ports'.
		html tableHeading ]! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 4/4/2008 22:25'!
renderInputFirstOn: html
	html tableRow: [
		self renderInputForCookie: #first on: html.
		html tableData: [
			html submitButton
				on: #addFirst of: self ] ]! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 4/4/2008 22:22'!
renderInputForCookie: aSymbol on: html
	html tableData: [
		html textInput
			on: (aSymbol, #Key) asSymbol of: self ].
	html tableData: [
		html textInput
			on: (aSymbol, #Value) asSymbol of: self ].
	html tableData: [
		html textInput
			on: (aSymbol, #Path) asSymbol of: self ].
	html tableData.
	html tableData.! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 4/4/2008 22:27'!
renderInputOn: html
	self renderInputFirstOn: html.
	self renderInputSecondOn: html! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 4/4/2008 22:25'!
renderInputSecondOn: html
	html tableRow: [
		self renderInputForCookie: #second on: html.
		html tableData: [
			html submitButton
				on: #addBoth of: self ] ]! !

!WACookieFunctionalTest methodsFor: 'rendering-explanation' stamp: 'pmm 4/5/2008 14:08'!
renderOperaOn: html
	html listItem: 'Opera is supposed to work perfectly.'! !

!WACookieFunctionalTest methodsFor: 'rendering-explanation' stamp: 'pmm 4/5/2008 17:46'!
renderRemoveOn: html
	html listItem: 'Removing should work on Firefox and Safari but only if the path is unchanged. On Opera it should delete the value and the path.'! !

!WACookieFunctionalTest methodsFor: 'rendering-explanation' stamp: 'pmm 4/5/2008 14:07'!
renderSafariOn: html
	html listItem: 'On Safari the path is not supposed to work. But if you look under Preferences -> Security -> Show Cookies the cookie should be saved with the correct path.'! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'lr 4/9/2008 10:42'!
secondCookie
	^self requestContext newCookie
		key: self secondKey;
		value: self secondValue;
		path: self secondPath;
		yourself! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:12'!
secondKey
	^ secondKey! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:31'!
secondKey: aString
	secondKey := aString! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:12'!
secondPath
	^ secondPath! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:31'!
secondPath: aString
	secondPath := aString! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:12'!
secondValue
	^ secondValue! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:31'!
secondValue: aString
	secondValue := aString! !

WAFunctionalTest subclass: #WADateSelectorFunctionalTest
	instanceVariableNames: 'beginDate endDate beginTime endTime beginDAT endDAT'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WADateSelectorFunctionalTest class methodsFor: 'examples' stamp: 'lr 10/28/2007 14:42'!
example
	^self new! !

!WADateSelectorFunctionalTest class methodsFor: 'class initialization' stamp: 'lr 6/13/2006 16:10'!
initialize
	self registerAsApplication: 'tests/dateselector'! !

!WADateSelectorFunctionalTest methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
children
	^(OrderedCollection new)
		add: beginDate;
		add: endDate;
		add: beginTime;
		add: endTime;
		add: beginDAT;
		add: endDAT;
		yourself! !

!WADateSelectorFunctionalTest methodsFor: 'actions' stamp: 'pmm 8/31/2008 14:24'!
computeDuration
	| dateDiff |
	dateDiff := (endDAT dateAndTime asDate - beginDAT dateAndTime asDate) days.
	dateDiff isZero 
		ifFalse: [ self inform: dateDiff seasideString, ' day(s)' ]
		ifTrue: [ self inform: (endDAT dateAndTime asTime subtractTime: beginDAT dateAndTime asTime) asSeconds seasideString, ' second(s)' ]! !

!WADateSelectorFunctionalTest methodsFor: 'initialization' stamp: 'dkh 3/7/2008 11:24'!
initialize
	super initialize.
	beginDate := WADateSelector new.
	endDate := WADateSelector new.
	endDate date: (Date today addDays: 1).

	beginTime := WATimeSelector new.
	beginTime time: Time now.
	endTime := WATimeSelector new.
	endTime time: (beginTime time addSeconds: 3600).

	beginDAT := WADateTimeSelector new.
	endDAT := WADateTimeSelector new.
	endDAT dateAndTime: beginDAT dateAndTime + 1 days + 1 hours! !

!WADateSelectorFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderContentOn: html

	self renderDateSelectorsOn: html.
	html horizontalRule.
	self renderTimeSelectorsOn: html.
	html horizontalRule.
	self renderDateTimeSelectorsOn: html! !

!WADateSelectorFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:47'!
renderDateSelectorsOn: html 
	html heading
		level3;
		with: 'Dates'.
	html form: [
		html table: [
			html tableRow: [
				html
					tableData: 'From';
					tableData: beginDate ].
			html tableRow: [
				html
					tableData: 'To';
					tableData: endDate ] ].
		html div: [
			html submitButton
				callback: [ self inform: (endDate date - beginDate date) days seasideString, ' day(s)' ];
				text: 'Compute duration' ] ]! !

!WADateSelectorFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:47'!
renderDateTimeSelectorsOn: html
	html heading level3; with: 'Dates and Times'.
	html form: [
		html table: [
			html tableRow: [
				html tableData: 'From'; tableData: beginDAT ].
			html tableRow: [
				html tableData: 'To'; tableData: endDAT ] ].
		html div: [
			html submitButton
				callback: [ self computeDuration ];
				text: 'Compute duration' ] ]! !

!WADateSelectorFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:48'!
renderTimeSelectorsOn: html 
	html heading
		level3;
		with: 'Times'.
	html form:  [
		html table:  [
			html tableRow: [
				html
					tableData: 'From';
					tableData: beginTime ].
			html tableRow:  [
				html
					tableData: 'To';
					tableData: endTime ] ].
		html div: [
			html submitButton
				callback:  [ self inform: (endTime time subtractTime: beginTime time) asSeconds seasideString, ' seconds(s)' ];
				text: 'Compute duration' ] ]! !

WAFunctionalTest subclass: #WADateTimeFunctionalTest
	instanceVariableNames: 'data numericData date time data1 data2 message'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:25'!
data1
	^data1! !

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:26'!
data1: aString
	data1 := aString! !

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:25'!
data2
	^data2! !

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:26'!
data2: aString
	data2 := aString! !

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:22'!
date
	^date! !

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
date: aDate
	date := aDate! !

!WADateTimeFunctionalTest methodsFor: 'initialize-release' stamp: 'lr 10/28/2007 14:42'!
initialize
	super initialize.
	data1 := 'Harry'.
	data2 := 'Covert'.
	data := String new.
	message := String new.
	numericData := 12! !

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:26'!
numericData
	^numericData! !

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:26'!
numericData: aString
	numericData := aString! !

!WADateTimeFunctionalTest methodsFor: 'rendering' stamp: 'pmm 7/10/2007 21:19'!
renderContentOn: html

	self renderSubmitFormOn: html.
	self renderDateTimeOn: html.
	self renderDeadDateTimeOn: html! !

!WADateTimeFunctionalTest methodsFor: 'rendering' stamp: 'pmm 8/31/2008 14:27'!
renderDateTimeOn: html 
	html heading
		level3;
		with: 'Form with #dateInput and #timeInput'.
	html form
		defaultAction: [ message := 'Default action: ' , date seasideString, ' ', time seasideString ];
		with:  [
			html div: [
				html dateInput on: #date of: self.
				html space: 10.
				html timeInput
					withSeconds;
					on: #time of: self.
				html break.
				html text: message.
				html break.
				html submitButton
					callback: [ message := 'Button action: ', date seasideString , ' ', time seasideString ] ] ]! !

!WADateTimeFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderDeadDateTimeOn: html
	html heading level: 3;
		 with: 'Div with #dateInput and #timeInput, no callback'.
	html form: [
		html div: [
			html dateInput value: Date today.
			html space: 10.
			html timeInput withSeconds; value: Time now.
			html break.
			html withLineBreaks: 'The year portion of the date should be visible.
				The seconds portion of the time should be visible' ] ]! !

!WADateTimeFunctionalTest methodsFor: 'rendering' stamp: 'pmm 8/31/2008 14:29'!
renderSubmitFormOn: html 
	html heading
		level3;
		with: 'Form with #submitFormNamed:'.
	html form
		id: 'submitForm';
		defaultAction: [ data := 'Default action : ' , data1 seasideString , ' ' , data2 seasideString , ' ' , numericData seasideString ];
		with: [
			html div: [
				html textInput on: #data1 of: self.
				html textInput on: #data2 of: self.
				html textInput on: #numericData of: self.
				html break.
				html text: data.
				html break.
				html anchor
					callback: [ data := 'Anchor action : ', data1 seasideString, ' ', data2 seasideString, ' ', numericData seasideString ];
					submitFormNamed: 'submitForm';
					with: 'Click to submit' ] ]! !

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:23'!
time
	^time! !

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:23'!
time: aTime
	time := aTime! !

WAFunctionalTest subclass: #WADecorationTest
	instanceVariableNames: 'task'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WADecorationTest commentStamp: 'lr 5/31/2008 10:58' prior: 0!
http://code.google.com/p/seaside/issues/detail?id=71!

!WADecorationTest methodsFor: 'accessing' stamp: 'lr 5/31/2008 11:18'!
children
	^ Array with: task! !

!WADecorationTest methodsFor: 'initialize-release' stamp: 'lr 5/31/2008 15:50'!
initialize
	super initialize.
	task := WADecorationTask new! !

!WADecorationTest methodsFor: 'rendering' stamp: 'lr 9/13/2008 17:13'!
renderContentOn: html
	html orderedList: [
		html listItem: 'Click button of Step 1'.
		html listItem: 'Click back-button'.
		html listItem: 'Click button of Step 1'.
		html listItem: 'Click button of Step 2' ].
	html paragraph: 'Step 1 and Step 2 should have consistent number of visible presenters. Especially there should never be two WAAnswerDecorations.'.
	
	html heading level: 2; with: 'Application'.
	html render: task.
	
	html heading level: 2; with: 'Visible Presenters'.
	html table: [
		html tableRow: [
			html tableHeading: 'Presenter'.
			html tableHeading.
			html tableHeading: 'Next'.
			html tableHeading ].
		self visiblePresentersDo: [ :each |
			html tableRow: [
				html tableData: each printString.
				html tableData: each identityHash.
				html tableData: (each isDecoration
					ifTrue: [ each owner printString ]
					ifFalse: [ each decoration printString ]).
				html tableData: (each isDecoration
					ifTrue: [ each next identityHash ]
					ifFalse: [ each decoration identityHash ]) ] ] ]! !

WAFunctionalTest subclass: #WADelayFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WADelayFunctionalTest methodsFor: 'actions' stamp: 'lr 5/22/2007 18:12'!
go
	self call: (WAComponent new
		addMessage: '3 seconds';
		addDecoration: (WADelayedAnswerDecoration new delay: 3);
		yourself)! !

!WADelayFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/2/2007 00:20'!
renderContentOn: html
	html paragraph: 'Clicking the following anchor should replace it with the message "3 seconds" for 3 seconds and then restore it.'.
	html paragraph: [
		html anchor
			callback: [ self go ];
			with: 'Start' ]! !

WAFunctionalTest subclass: #WAEncodingFunctionalTest
	instanceVariableNames: 'urlencoded multipart get'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAEncodingFunctionalTest commentStamp: 'pmm 6/22/2007 20:35' prior: 0!
A WAEncodingTest test whether Seaside correctly handles non-ASCII strings. Unfortunately due to differences in server setup and source code encodings this test requires manual interaction.
!

!WAEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/9/2008 19:46'!
get
	^ get! !

!WAEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/9/2008 19:47'!
get: aString
	get := aString! !

!WAEncodingFunctionalTest methodsFor: 'initialize-release' stamp: 'pmm 5/9/2008 19:52'!
initialize
	super initialize.
	self urlencoded: 'urlencoded'.
	self multipart: 'multipart'.
	self get: 'get'! !

!WAEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 6/22/2007 20:21'!
multipart
	^multipart! !

!WAEncodingFunctionalTest methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
multipart: aString
	multipart := aString! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/9/2008 19:50'!
renderCharacterByCharacter: aString on: html
	self usesSmalltalkEncoding
		ifTrue: [
			html table with: [
				html tableRow: [
					1 to: aString size do: [ :index | 
						html tableData: (aString species with: (aString at: index)) ] ] ] ]
		ifFalse: [ html render: aString ]! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:49'!
renderClassName: aString on: html 
	aString isNil ifTrue: [ ^ self ].
	html paragraph: [
		html strong: 'Class: '.
		html text: aString class name ]! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/11/2008 16:41'!
renderContentOn: html
	self renderExplanationOn: html.
	self renderUrlencodedOn: html.
	self renderMultipartOn: html.
	self renderGetOn: html! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 09:49'!
renderExplanationOn: html
	html unorderedList: [
		html listItem: [
			html text: 'Go to the '.
			html anchor
				url: 'http://www.columbia.edu/kermit/utf8.html';
				with: 'UTF-8 Sampler'.
			html text: ' and select some "foreign" text.' ].
		html listItem: 'Copy and paste it into the urlencoded text field below and click the submit button.'.
		html listItem: 'The heading, textfield, character field and submitt button should all display the text without any error.'.
		html listItem: 'Submit again without changing anything, again everything should display normally.'.
		html listItem: 'Repeat this process for the multipart field. Make sure to pick at least every of these languages: German, Czech, Korean.' ]! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 09:50'!
renderGetOn: html

	html heading level2;
		with: 'GET'.
	html heading level3;
		with: self get.
	self renderCharacterByCharacter: self get on: html.
	html form
		get;
		with: [
			html div: [
				html textInput
					on: #get of: self.
				html submitButton
					text: self get ] ].
	self renderClassName: self get on: html! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 09:50'!
renderMultipartOn: html

	html heading level2;
		with: 'Multipart'.
	html heading level3;
		with: self multipart.
	self renderCharacterByCharacter: self multipart on: html.
	html form
		multipart;
		with: [
			html div: [
				html textInput
					on: #multipart of: self.
				html submitButton
					text: self multipart ] ].
	self renderClassName: self multipart on: html! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 09:50'!
renderUrlencodedOn: html

	html heading level2;
		with: 'Urlencoded'.
	html heading level3;
		with: self urlencoded.
	self renderCharacterByCharacter: self urlencoded on: html.
	html form: [
		html div: [
			html textInput
				on: #urlencoded of: self.
			html submitButton
				text: self urlencoded ] ].
	self renderClassName: self urlencoded on: html! !

!WAEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/2/2007 00:04'!
urlencoded
	^urlencoded! !

!WAEncodingFunctionalTest methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
urlencoded: aString
	urlencoded := aString! !

!WAEncodingFunctionalTest methodsFor: 'testing' stamp: 'pmm 5/9/2008 19:49'!
usesSmalltalkEncoding
	^self requestContext usesSmalltalkEncoding! !

WAFunctionalTest subclass: #WAErrorFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAErrorFunctionalTest methodsFor: 'actions' stamp: 'pmm 9/14/2008 15:36'!
answerNil
	self requestContext returnResponse: nil! !

!WAErrorFunctionalTest methodsFor: 'actions' stamp: 'pmm 9/14/2008 15:36'!
answerObject
	self requestContext returnResponse: Object new! !

!WAErrorFunctionalTest methodsFor: 'actions' stamp: 'jf 9/24/2008 21:52'!
raiseDeprecated
	self seasideDeprecatedApi: 'Test action phase deprecation'
		details: 'action details'.
	self inform: [ :html |
		self seasideDeprecatedApi: 'Test render phase deprecation'	
			details: 'render details'.
		html paragraph: 'To be displayed' ]! !

!WAErrorFunctionalTest methodsFor: 'actions' stamp: 'lr 3/24/2008 18:11'!
raiseError
	self error: 'Test Error'.
	self inform: 'Not to be displayed'! !

!WAErrorFunctionalTest methodsFor: 'actions' stamp: 'jf 9/23/2008 20:24'!
raiseHalt
	| context |
	self halt.
	"You should be able to step over the following line and have the current request context
	successfully stored in the variable.
	You should also (ideally anyway, it works on Squeak) be able to Inspect the value of
	'self requestContext' in the Debugger and get a result.
	Finally, you should be able to restart this method in the Debugger and do the above
	again successfully."
	context := self requestContext.
	self inform: 'To be displayed'! !

!WAErrorFunctionalTest methodsFor: 'actions' stamp: 'lr 3/24/2008 18:11'!
raiseResumable
	1 / 0.
	self inform: 'To be displayed'! !

!WAErrorFunctionalTest methodsFor: 'actions' stamp: 'lr 3/24/2008 18:11'!
raiseWarning
	self notify: 'Test Warning'.
	self inform: 'To be displayed'! !

!WAErrorFunctionalTest methodsFor: 'rendering' stamp: 'jf 9/17/2008 20:22'!
renderContentOn: html
	html div class: 'errorTest'; with: [
		self renderHandlerConfigurationOn: html.
		self renderHaltOn: html.
		self renderErrorOn: html.
		self renderResumableErrorOn: html.
		self renderWarningOn: html.
		self renderDeprecatedOn: html.
		self renderNilOn: html.
		self renderObjectOn: html ]! !

!WAErrorFunctionalTest methodsFor: 'rendering' stamp: 'jf 9/24/2008 21:57'!
renderDeprecatedOn: html 
	html heading: 'Deprecated'.
	html paragraph: 'The link should cause a deprecated warning to appear in the toolbar. Clicking on the link should display two action deprecations and two render deprecations.'.
	html anchor
		callback: [ self raiseDeprecated ];
		with: 'Raise deprecated'! !

!WAErrorFunctionalTest methodsFor: 'rendering' stamp: 'jf 9/23/2008 20:26'!
renderErrorOn: html 
	html heading: 'Error'.
	html paragraph: 'The link should display an error walkback. Opening a debugger should work. Closing the debugger window should not lock the session. Proceeding the error should display a friendly error page in the browser.'.
	html anchor
		callback: [ self raiseError ];
		with: 'Raise error'! !

!WAErrorFunctionalTest methodsFor: 'rendering' stamp: 'jf 9/23/2008 20:26'!
renderHaltOn: html 
	html heading: 'Halt'.
	html paragraph: 'The link should open a debugger in the image. There are comments in the #raiseHalt method suggesting other things that should be tested from within the Debugger. Clicking on proceed should display the information message "To be displayed".'.
	html anchor
		callback: [ self raiseHalt ];
		with: 'Halt execution'! !

!WAErrorFunctionalTest methodsFor: 'rendering' stamp: 'jf 10/5/2008 14:38'!
renderHandlerConfigurationOn: html
	| attribute |
	attribute := self application configuration
		attributeAt: #exceptionHandler
		ifAbsent: [
			html paragraph: 'Exception handler configuration attribute not found!!'.
			^ self ].

	html form: [
		html div: [
			html select
				beOptional;
				optionalLabel: '(inherited default)';
				list: attribute options asArray;
				selected: (self application configuration at: attribute key);
				callback: [ :value | self application configuration takeValue: value forAttribute: attribute ].
			html submitButton with: 'Set Handler' ] ]! !

!WAErrorFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/14/2008 15:44'!
renderNilOn: html
	html heading: 'Nil response'.
	html paragraph: 'The link should return an internal server error. A nil response might get passed to the server adapter if some strange things happen in the error handling, possibly including debuggers.'.
	html anchor
		callback: [ self answerNil ];
		with: 'answer nil'! !

!WAErrorFunctionalTest methodsFor: 'rendering' stamp: 'jf 9/17/2008 20:33'!
renderObjectOn: html
	html heading: 'Inappropriate response'.
	html paragraph: 'This link triggers returning an inappropriate object as a response. It should, however, be handled relatively gracefully by the server adaptor.'.
	html anchor
		callback: [ self answerObject ];
		with: 'answer inappropriate object'! !

!WAErrorFunctionalTest methodsFor: 'rendering' stamp: 'lr 3/24/2008 18:11'!
renderResumableErrorOn: html 
	html heading: 'Resumable error'.
	html paragraph: 'The link should display a zero divide walkback. Clicking on proceed should display the message "To be displayed". Clicking on debug should open a debugger in the image.'.
	html anchor
		callback: [ self raiseResumable ];
		with: 'Raise zero divide'! !

!WAErrorFunctionalTest methodsFor: 'rendering' stamp: 'lr 3/24/2008 18:11'!
renderWarningOn: html 
	html heading: 'Warning'.
	html paragraph: 'In Squeak the warning test works the same as the resumable error test.'.
	html paragraph: 'In VisualWorks the warning test works the same as the halt test.'.
	html anchor
		callback: [ self raiseWarning ];
		with: 'Raise warning'! !

WAFunctionalTest subclass: #WAExpiryFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAExpiryFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:54'!
renderActionsOn: html
	html paragraph: [
		html anchor
			url: self session newSessionUrl;
			 with: 'New Session'.
		html break.
		html anchor
			callback: [ self session expire ];
			 with: 'Expire'.
		html break.
		html anchor
			callback: [ WAExpirySession resetCounters ];
			 with: 'Reset Counters'.
		html break.
		html anchor
			callback: [ Smalltalk garbageCollect ];
			 with: 'Garbage Collect'.
		html break.
		html anchor
			callback: [
				self application clearHandlers.
				Smalltalk garbageCollect ];
			 with: 'Clear Handlers'.
		html break.
		html anchor
			callback: [
				self application clearHandlers.
				WAExpirySession resetCounters.
				Smalltalk garbageCollect ];
			 with: 'Reset All' ]. 
	html form: [
		html div: [
			html text: 'Expiry seconds:'.
			html textInput
				value: self session sessionExpirySeconds;
				callback: [ :value | self session timeoutSeconds: value asInteger ].
			html space.
			html submitButton
				text: 'Change' ] ]! !

!WAExpiryFunctionalTest methodsFor: 'rendering' stamp: 'pmm 7/31/2007 07:17'!
renderContentOn: html
	self renderStatsOn: html.
	self renderActionsOn: html! !

!WAExpiryFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderStatsOn: html
	html table: [
		html tableRow: [
			html tableHeading: 'Total session instances'.
			html tableData: WAExpirySession allInstances size ].
		html tableRow: [
			html tableHeading: 'Active session instances'.
			html tableData: (WAExpirySession allInstances count: [ :each | each isActive ]) ].
		html tableRow: [
			html tableHeading: 'Total component instances'.
			html tableData: self class allInstances size ].
		html tableRow: [
			html tableHeading: 'Sessions created'.
			html tableData: WAExpirySession created ].
		html tableRow: [
			html tableHeading: 'Sessions unregistered'.
			html tableData: WAExpirySession unregistered ] ]! !

WAFunctionalTest subclass: #WAFilterFunctionalTest
	instanceVariableNames: 'child'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAFilterFunctionalTest methodsFor: 'actions' stamp: 'lr 8/31/2008 15:17'!
authentication
	self authenticateWith: self during: [ child inform: 'Congratulations, you have been authenticated. The new filter should be visible in the list above. Clicking on "ok" should remove the filter. Using the back button and hitting refresh should show the filter again.' ]! !

!WAFilterFunctionalTest methodsFor: 'accessing' stamp: 'lr 8/31/2008 15:12'!
children
	^ Array with: child! !

!WAFilterFunctionalTest methodsFor: 'initialization' stamp: 'lr 8/31/2008 15:12'!
initialize
	super initialize.
	child := WAComponent new! !

!WAFilterFunctionalTest methodsFor: 'actions' stamp: 'lr 8/31/2008 15:15'!
protector
	self filterWith: WAProtectionFilter new during: [ child inform: 'Open this page on a different computer by copying the complete URL to a machine with a different IP address. Seaside should reply with a forbidden message. Closing this dialog should remove the filter.' ]! !

!WAFilterFunctionalTest methodsFor: 'rendering' stamp: 'lr 8/31/2008 15:16'!
renderActionsOn: html
	html paragraph: [
		html anchor
			callback: [ self authentication ];
			with: 'Basic Authentication'.
		html text: ' (admin/seaside)'.
		html break.
		html anchor
			callback: [ self protector ];
			with: 'Session Protector' ].
	html horizontalRule.
	html paragraph: self children! !

!WAFilterFunctionalTest methodsFor: 'rendering' stamp: 'lr 8/31/2008 15:08'!
renderContentOn: html
	self renderFiltersOn: html.
	self renderActionsOn: html! !

!WAFilterFunctionalTest methodsFor: 'rendering' stamp: 'lr 8/31/2008 15:41'!
renderFiltersOn: html
	self session isFiltered ifFalse: [ ^ self ].
	html paragraph: 'Below a list of filters wrapping the current session:'.
	html orderedList list: self session filters! !

!WAFilterFunctionalTest methodsFor: 'private' stamp: 'lr 8/31/2008 15:01'!
verifyPassword: aPasswordString forUser: aUserString
	^ aUserString = 'admin' and: [ aPasswordString = 'seaside' ]! !

WAFunctionalTest subclass: #WAFlowFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAFlowFunctionalTest methodsFor: 'actions' stamp: 'pmm 8/31/2008 14:32'!
goAnchors
	| component |
	1 to: 5 do: [ :each | 
		component := WAComponent new.
		component addMessage: [ :html | 
			html anchor
				callback: [ component answer ];
				with: each seasideString , ': ' , self stackDepth seasideString ] fixCallbackTemps.
		self call: component ]! !

!WAFlowFunctionalTest methodsFor: 'actions' stamp: 'pmm 8/31/2008 14:33'!
goButtons
	1 to: 5 do: [ :each |
		self inform: each seasideString, ': ', self stackDepth seasideString ]! !

!WAFlowFunctionalTest methodsFor: 'rendering' stamp: 'lr 5/22/2007 18:10'!
renderContentOn: html
	html paragraph: 'The following two anchors should trigger flows with 5 steps each. The stack should neither grow nor shrink. Backtracking and spawning of windows should properly work.'.
	html paragraph: [
		html anchor
			callback: [ self goAnchors ];
			with: 'go anchors'.
		html break.
		html anchor
			callback: [ self goButtons ];
			with: 'go buttons' ]! !

!WAFlowFunctionalTest methodsFor: 'private' stamp: 'dkh 3/3/2008 20:33'!
stackDepth

	^SeasidePlatformSupport stackDepth! !

WAFunctionalTest subclass: #WAGetInputFunctionalTest
	instanceVariableNames: 'inputElements'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAGetInputFunctionalTest class methodsFor: 'accessing' stamp: 'pmm 8/31/2008 17:59'!
description
	^'Various XHTML form input elements'! !

!WAGetInputFunctionalTest class methodsFor: 'accessing' stamp: 'pmm 8/31/2008 17:59'!
example

	^ self new! !

!WAGetInputFunctionalTest methodsFor: 'accessing' stamp: 'pmm 8/31/2008 17:59'!
children
	^Array with: inputElements! !

!WAGetInputFunctionalTest methodsFor: 'initialization' stamp: 'pmm 8/31/2008 17:59'!
initialize
	super initialize.
	inputElements := WAInputElementContainer new! !

!WAGetInputFunctionalTest methodsFor: 'rendering' stamp: 'pmm 8/31/2008 17:59'!
renderContentOn: html
	html form
		get;
		with: [
			html table: inputElements.
			html div: [
				"div for validation"
				html submitButton ] ]! !

WAFunctionalTest subclass: #WAHomeFunctionalTest
	instanceVariableNames: 'main'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAHomeFunctionalTest methodsFor: 'accessing' stamp: 'avi 10/19/2004 15:53'!
children
	^ Array with: main! !

!WAHomeFunctionalTest methodsFor: 'initialize-release' stamp: 'lr 2/28/2008 09:54'!
initialize
	super initialize.
	main := self message: 'Root Component'! !

!WAHomeFunctionalTest methodsFor: 'accessing' stamp: 'lr 2/28/2008 09:54'!
message: aString
	^ WAComponent new
		addMessage: aString;
		yourself! !

!WAHomeFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:55'!
renderContentOn: html
	html paragraph: 'Clicking home should always bring back the root component.'.
	html paragraph: [
		html anchor
			callback: [ main call: (self message: 'Called Component') ];
			with: 'call'.
		html space.
		html anchor
			callback: [ main home ];
			with: 'home' ].
	html render: main! !

WAFunctionalTest subclass: #WAHtmlFunctionalTest
	instanceVariableNames: 'booleanList message number'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAHtmlFunctionalTest methodsFor: 'accessing' stamp: 'mb 10/12/2006 19:43'!
allSelectors
	^ (self class selectors asSortedCollection select: [:s | s beginsWith: 'render'])
		remove: #renderContentOn:;
		yourself! !

!WAHtmlFunctionalTest methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
initialMessage
	^'Hello world!!'! !

!WAHtmlFunctionalTest methodsFor: 'initialize-release' stamp: 'lr 10/28/2007 14:42'!
initialize
	super initialize.
	message := self initialMessage.
	booleanList := #(a b c d) collect: [:key | key -> ((Array with: true with: false) atRandom)].
	number := 10 atRandom! !

!WAHtmlFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:33'!
message
	^message! !

!WAHtmlFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:33'!
message: aString
	message := aString! !

!WAHtmlFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:32'!
number
	^number! !

!WAHtmlFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:32'!
number: anInteger
	number := anInteger! !

!WAHtmlFunctionalTest methodsFor: 'rendering' stamp: 'pmm 6/9/2007 15:34'!
renderCheckboxesOn: html
	html text: booleanList.
	html paragraph.
	html form: [
		booleanList do: [:association |
			html text: association key; space.
			html checkbox
				addShortcut: 'Ctrl-' , association key asUppercase;
				on: #value of: association.
			html span
				class: 'indented'; class: 'hint';
				with: 'Shortcuts: ' , 'Ctrl-' , association key asUppercase.
			html break].
		html submitButton]! !

!WAHtmlFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderContentOn: html
	"don't use pairsDo:, doesn't work for JPMorgan"
	| selectors indices |
	selectors := self allSelectors.
	indices := (1 to: selectors size) select: [ :each | each odd ].
	indices do: [ :index |
		html div
			class: 'row';
			with: [
				html div
					class: 'left';
					with: [
						self
							perform: (selectors at: index)
							with: html ].
				index < selectors size ifTrue: [
					html div
						class: 'left';
						with: [
							self
								perform: (selectors at: index + 1)
								with: html ] ] ] ]! !

!WAHtmlFunctionalTest methodsFor: 'rendering' stamp: 'pmm 6/9/2007 15:34'!
renderRadioButtonsOn: html
	html text: booleanList.
	html paragraph.
	html form: [
		booleanList do: [ :association |
			| group |
			group := html radioGroup.
			html text: association key; space.
			group radioButton
				addShortcut: 'Ctrl-' , association key;
				selected: association value;
				callback: [ association value: true ].
			group radioButton
				addShortcut: 'Alt-' , association key;
				selected: association value not;
				callback: [ association value: false ].
			html span
				class: 'indented'; class: 'hint';
				with: 'Shortcuts: ' , 'Ctrl-' , association key , ' Alt-' , association key.
			html break ].
		html submitButton ]! !

!WAHtmlFunctionalTest methodsFor: 'rendering' stamp: 'pmm 7/19/2006 19:39'!
renderSelectsOn: html
	html text: number.
	html paragraph.
	html form: [
		html select
			list: (1 to: 10);
			on: #number of: self.
		html submitButton]! !

!WAHtmlFunctionalTest methodsFor: 'rendering' stamp: 'pmm 8/31/2008 14:36'!
renderSubmitButtonsOn: html 
	html text: number.
	html paragraph.
	html form: [
		1 to: 10 do: [ :index | 
			html submitButton
				addShortcut: 'F' , index seasideString;
				callback: [ number := index ];
				text: index.
			html space ] ].
	html span
		class: 'hint';
		with: 'Above, you may be able to use F1 .. F10 as shortcuts, if the browser allows you.'! !

!WAHtmlFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderTextAreaOn: html
	| position |
	position := message = self initialMessage
		ifTrue: [ 6 ]
		ifFalse: [ 'End' ].
	html form: [
		html text: message.
		html paragraph
			class: 'hint';
			with: 'The text area below should have the focus and be wholly selected, unless it has its initial value, ' , self initialMessage printString , ', in which case you should see the cursor right after the "o" of "Hello".'.
		html textArea
			setCursorPosition: position;
			on: #message of: self.
		html break.
		html submitButton ]! !

!WAHtmlFunctionalTest methodsFor: 'rendering' stamp: 'pmm 7/19/2006 19:34'!
renderTextInputOn: html
	html form: [
		html text: message.
		html paragraph.
		html textInput
			on: #message of: self.
		html submitButton]! !

!WAHtmlFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderVFieldSetOn: html
	html fieldSet
		legend: 'Various text rendering in a fieldset';
		with: [
			html
				strong: 'Strong';
				break;
				emphasis: 'Emphasis';
				break.
			html acronym
				title: 'United States of America';
				with: 'USA'.
			html
				break;
				emphasis: 'Emphasis';
				break.

			html div
				style: 'color: red';
				style: 'background-color: lightgreen';
				style: 'padding: 1em';
				style: 'border: solid 2px black';
				style: 'font-weight: bold';
				style: 'font-size: 150%';
				style: 'height: 3em';
				style: 'text-align: center';
				with: 'Large bold red in a green div'.
			html
				break]! !

!WAHtmlFunctionalTest methodsFor: 'rendering' stamp: 'MAD 8/30/2008 11:12'!
renderZFieldSetOn: html
	| url |
	url := html context
		urlForDocument: (WATestingFiles default inspectorPng)
		mimeType: 'image/png'
		fileName: 'Debug.jpg'.
	html fieldSet
		legend: 'Various images in a fieldset';
		with: [html image url: url; altText: 'Halo-Debug'.
			html space.
			html break.
			html image url: WATestingFiles / #styleeditorPng; width: '80%'; altText: 'Style Editor'.
			html break.
			html image url: WATestingFiles / #styleeditorPng; height: '50px'; altText: 'Style Editor'.
			html break.
			html image url: WATestingFiles / #styleeditorPng; width: '250px'; height: '60px'; altText: 'Style Editor' ]! !

!WAHtmlFunctionalTest methodsFor: 'rendering' stamp: 'mb 6/10/2007 19:34'!
style
	^ '
div.row {
	clear: both
}

div.left {
	float: left;
	width: 45%;
	margin: 1%
}

.indented {
	margin-left: 2em;
}

.hint {
	font-family: Tahoma, Arial;
	font-size: small;
}
'! !

WAFunctionalTest subclass: #WAIframeFunctionalTest
	instanceVariableNames: 'counter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAIframeFunctionalTest methodsFor: 'accessing' stamp: 'lr 3/9/2006 13:31'!
children
	^ Array with: counter! !

!WAIframeFunctionalTest methodsFor: 'initialization' stamp: 'lr 3/9/2006 13:31'!
initialize
	super initialize.
	counter := WACounter new! !

!WAIframeFunctionalTest methodsFor: 'rendering' stamp: 'MAD 8/30/2008 11:18'!
renderContentOn: html
	html iframe
		contents: counter.
	html break; break.
	html iframe
		url: (WADispatcher default entryPointAt: WACounter entryPointName) baseUrl.
	html break; break.
	html iframe
		document: WATestingFiles default styleeditorPng
		mimeType: 'image/png'! !

!WAIframeFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
style
	^ 'iframe {
	border: 1px solid gray;
	width: 100%;
}'! !

WAFunctionalTest subclass: #WAImageMapFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAImageMapFunctionalTest methodsFor: 'actions' stamp: 'pmm 8/31/2008 14:36'!
clickedAt: aPoint id: aString 
	self inform: 'Clicked at ', aPoint seasideString, ' on ', aString seasideString! !

!WAImageMapFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:57'!
renderContentOn: html
	html heading level: 3;
		 with: 'A byte array with server side map (ismap)'.
		
	html paragraph: 'Click anywhere on the Style Editor icon and you should get informed about the position where you clicked.'.
		
	html paragraph: [
		html map title: 'Click anywhere on the style editor icon';
			callback: [ :aPoint |
				self clickedAt: aPoint id: 'the Style Editor Icon'];
			with: [
				html image
				altText: 'Style Editor Icon';
					width: '40%';
					url: WATestingFiles / #styleeditorPng ] ]! !

WAFunctionalTest subclass: #WAInputFunctionalTest
	instanceVariableNames: 'inputElements'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAInputFunctionalTest class methodsFor: 'accessing' stamp: 'mb 2/22/2007 14:42'!
description
	^'Various XHTML form input elements'! !

!WAInputFunctionalTest class methodsFor: 'accessing' stamp: 'mb 2/22/2007 14:41'!
example

	^ self new! !

!WAInputFunctionalTest methodsFor: 'accessing' stamp: 'pmm 9/19/2007 06:55'!
children
	^Array with: inputElements! !

!WAInputFunctionalTest methodsFor: 'initialization' stamp: 'pmm 9/19/2007 06:49'!
initialize
	super initialize.
	inputElements := WAInputElementContainer new! !

!WAInputFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 10:01'!
renderContentOn: html
	html form: [
		html table: inputElements.
		html div: [
			"div for validation"
			html submitButton ] ]! !

WAFunctionalTest subclass: #WALinkSubmitFunctionalTest
	instanceVariableNames: 'count'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WALinkSubmitFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:45'!
count
	^count! !

!WALinkSubmitFunctionalTest methodsFor: 'accessing' stamp: 'pmm 12/9/2007 12:29'!
count: anIntegerOrString
	count := anIntegerOrString asInteger! !

!WALinkSubmitFunctionalTest methodsFor: 'initialize-release' stamp: 'lr 10/28/2007 14:42'!
initialize
	super initialize.
	count := 0! !

!WALinkSubmitFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:59'!
renderContentOn: html
	| formId |
	formId := #myform.
	html form
		id: formId;
		with: [
			html div: [
				html textInput
					on: #count of: self.
				html break.
				html anchor
					id: #decreaseLink;
					addShortcut: 'Ctrl-Down';
					callback: [ count := count - 1 ];
					submitFormNamed: formId;
					with: '--'.
				html space.
				html anchor
					id: #increaseLink;
					addShortcut: 'Ctrl-Up';
					callback: [ count := count + 1 ];
					submitFormNamed: formId;
					with: '++'.
				html break; break.
				count = 0 ifFalse: [
					html checkbox
						addShortcut: 'Ctrl-Z';
						addShortcut: 'Ctrl-z';
						value: (count = 0);
						callback: [ :value | value ifTrue: [ count := 0 ] ];
						submitFormNamed: formId.
					html space.
					html text: 'Reset' ] ] ].
	html paragraph: [
		html emphasis: 'Handy shortcuts : Ctrl-Up, Ctrl-Down and Ctrl-Z' ]! !

WAFunctionalTest subclass: #WALotsaLinksFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WALotsaLinksFunctionalTest methodsFor: 'rendering' stamp: 'pmm 8/31/2008 14:41'!
renderContentOn: html 
	self renderExplanationOn: html.
	html unorderedList: [
		1 to: 5000 do: [ :each | 
			html listItem: [
				html anchor
					name: each seasideString;
					callback: [
						self inform: each.
						self session jumpToAnchor: each seasideString ];
					with: each ] ] ]! !

!WALotsaLinksFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/29/2008 21:51'!
renderExplanationOn: html
	html paragraph: [
		html text: 'This test serves three purposes:'.
		html orderedList: [
			html listItem: 'First it is a regression test, earlier versions of Seaside could only handle a limited number of callbacks per page. The oldest links (low numbers) would use thier callback. Clicking on any link should display this number with a button.'.
			html listItem: 'Second it serves as a raw rendering speed benchmark.'.
			html listItem: 'Third it tests WASession >> #jumpToAnchor:. After confirming the number you should return to the page and be automacitally a at the place where the link is.' ] ]! !

WAFunctionalTest subclass: #WAMiniCalendarFunctionalTest
	instanceVariableNames: 'calendar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAMiniCalendarFunctionalTest methodsFor: 'accessing' stamp: 'pmm 9/11/2007 06:49'!
children
	^Array with: calendar! !

!WAMiniCalendarFunctionalTest methodsFor: 'initialize-release' stamp: 'pmm 9/11/2007 06:48'!
initialize
	super initialize.
	calendar := WAMiniCalendar new! !

!WAMiniCalendarFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 14:16'!
renderContentOn: html
	html render: calendar.

	html div: [
		html strong: 'selected:'.
		html space.
		html render: calendar date ]! !

WAFunctionalTest subclass: #WAModelFunctionalTest
	instanceVariableNames: 'state user pass test'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAModelFunctionalTest methodsFor: 'actions' stamp: 'mb 2/9/2006 15:25'!
logoff
	state := #OFF.
	test ifTrue: [self inform: 'Logged off']! !

!WAModelFunctionalTest methodsFor: 'actions' stamp: 'mb 2/9/2006 15:26'!
logon
	user isEmptyOrNil
		ifTrue:
			[self inform: 'Nope !!']
		ifFalse:
			[state := #ON.
			test ifTrue: [self inform: 'Logged on']]! !

!WAModelFunctionalTest methodsFor: 'accessing' stamp: 'mb 2/9/2006 15:04'!
pass
	"Answer the value of pass"

	^ pass! !

!WAModelFunctionalTest methodsFor: 'accessing' stamp: 'mb 2/9/2006 15:04'!
pass: anObject
	"Set the value of pass"

	pass := anObject! !

!WAModelFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 09:59'!
renderButtonOn: html
	| action |
	action := state == #ON ifTrue: [ #logoff ] ifFalse: [ #logon ].
	html div: [
		"div for validation"
		html submitButton
			on: action of: self ]! !

!WAModelFunctionalTest methodsFor: 'rendering' stamp: 'sh 8/30/2008 16:44'!
renderContentOn: html
	html form
		id: 'myform';
		with: [
			html table: [
				self renderUsernameOn: html.
				self renderPasswordOn: html.
				self renderFeedbackOn: html ].
			html div: [
				self renderButtonOn: html ]]! !

!WAModelFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/15/2007 19:49'!
renderFeedbackOn: html
	html tableRow: [
		html tableData: [
			html label
				for: #withFeedback;
				with: 'With Feedback:' ].
		html tableData: [
			html checkbox
				id: #withFeedback;
				on: #test of: self ] ]! !

!WAModelFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderPasswordOn: html
	html tableRow: [
		html tableData: [
			html label
				for: #pass;
				with: 'Password:' ].
		html tableData: [
			html passwordInput
				id: #pass;
				on: #pass of: self ] ]! !

!WAModelFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/15/2007 19:52'!
renderUsernameOn: html
	html tableRow: [
		html tableData: [
			html label
				for: #userid;
				with: 'Username:' ].
		html tableData: [
			html textInput
				id: #userid;
				on: #user of: self ] ]! !

!WAModelFunctionalTest methodsFor: 'accessing' stamp: 'mb 2/9/2006 15:04'!
test
	"Answer the value of test"

	^ test! !

!WAModelFunctionalTest methodsFor: 'accessing' stamp: 'mb 2/9/2006 15:04'!
test: anObject
	"Set the value of test"

	test := anObject! !

!WAModelFunctionalTest methodsFor: 'accessing' stamp: 'mb 2/9/2006 15:10'!
user
	"Answer the value of user"

	^ user! !

!WAModelFunctionalTest methodsFor: 'accessing' stamp: 'mb 2/9/2006 15:10'!
user: anObject
	"Set the value of user"

	user := anObject! !

WAFunctionalTest subclass: #WAMultipartInputFunctionalTest
	instanceVariableNames: 'inputElements'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAMultipartInputFunctionalTest class methodsFor: 'accessing' stamp: 'pmm 9/19/2007 06:50'!
description
	^'Various XHTML form input elements'! !

!WAMultipartInputFunctionalTest class methodsFor: 'accessing' stamp: 'pmm 9/19/2007 06:50'!
example

	^ self new! !

!WAMultipartInputFunctionalTest methodsFor: 'accessing' stamp: 'pmm 9/19/2007 06:55'!
children
	^Array with: inputElements! !

!WAMultipartInputFunctionalTest methodsFor: 'initialization' stamp: 'pmm 9/19/2007 06:50'!
initialize
	super initialize.
	inputElements := WAInputElementContainer new! !

!WAMultipartInputFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 10:00'!
renderContentOn: html
	html form
		multipart;
		with: [
			html table: inputElements.
			html div: [
				"div for validation"
				html submitButton ] ]! !

WAFunctionalTest subclass: #WAParameterFunctionalTest
	instanceVariableNames: 'wasExecuted values'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAParameterFunctionalTest commentStamp: 'pmm 5/12/2008 09:23' prior: 0!
A WAParameterFunctionalTest tests whether GET and POST fiedls are merged in WARequest >> #fields.!

!WAParameterFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/11/2008 12:20'!
actionUrlFor: html
	| url |
	url := html context actionUrl withoutParameters.
	url
		addParameter: self parameterName
		value: self firstParameterValue.
	^url! !

!WAParameterFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/11/2008 12:18'!
firstParameterValue
	^'firstValue'! !

!WAParameterFunctionalTest methodsFor: 'initialize-release' stamp: 'pmm 5/11/2008 12:14'!
initialize
	super initialize.
	wasExecuted := false! !

!WAParameterFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/11/2008 12:15'!
parameterName
	^'parameter'! !

!WAParameterFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/11/2008 12:39'!
renderContentOn: html
	self renderExplanationOn: html.
	wasExecuted
		ifTrue: [ self renderExecutedOn: html ]
		ifFalse: [ self renderNotExecutedOn: html ]! !

!WAParameterFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/11/2008 12:33'!
renderExecutedOn: html
	html strong: (self wasSuccessFull ifTrue: [ 'success' ] ifFalse: [ 'fail' ])! !

!WAParameterFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/11/2008 12:38'!
renderExplanationOn: html
	html paragraph: 'This test makes sure the server passes both GET and POST paramters to Seaside. Simply hit ''run test'' and ''success'' should be displayed. If ''fail'' is displayed or ''run test'' is displayed again then the test has failed.'! !

!WAParameterFunctionalTest methodsFor: 'rendering' stamp: 'pmm 8/31/2008 15:23'!
renderNotExecutedOn: html
	html form
		action: (self actionUrlFor: html);
		with: [
		 	html div: [
				html hiddenInput
					name: self parameterName;
					value: self secondParameterValue.
				html submitButton
					callback: [ self runTest ];
					text: 'run test' ] ]! !

!WAParameterFunctionalTest methodsFor: 'actions' stamp: 'pmm 5/11/2008 12:25'!
runTest
	values := self requestContext request at: self parameterName.
	wasExecuted := true! !

!WAParameterFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/11/2008 12:18'!
secondParameterValue
	^'secondValue'! !

!WAParameterFunctionalTest methodsFor: 'testing' stamp: 'pmm 5/11/2008 12:36'!
wasSuccessFull
	^values notNil
		and: [ values isCollection
		and: [ values isString not
		and: [ values size = 2
		and: [ (values includes: self firstParameterValue)
		and: [ (values includes: self secondParameterValue) ] ] ] ] ]! !

WAFunctionalTest subclass: #WAParentTest
	instanceVariableNames: 'parent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAParentTest methodsFor: 'actions' stamp: 'pmm 7/16/2007 20:06'!
go
	parent inform: 'Test green!!'! !

!WAParentTest methodsFor: 'accessing' stamp: 'ab 5/12/2003 22:13'!
parent: aComponent
	parent := aComponent! !

!WAParentTest methodsFor: 'rendering' stamp: 'pmm 7/16/2007 20:07'!
renderContentOn: html
	self renderExplanationOn: html.
	self renderSwapParentOn: html! !

!WAParentTest methodsFor: 'rendering' stamp: 'pmm 7/16/2007 20:07'!
renderExplanationOn: html
	html paragraph: 'This regression tests checks if #call: on the parent component works. If you click "swap parent" "Test green!!" should appear without a tab panel.'! !

!WAParentTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 14:17'!
renderSwapParentOn: html
	html paragraph: [
		html anchor
			callback: [ self go ];
			with: 'swap parent' ]! !

WAFunctionalTest subclass: #WAPathFunctionalTest
	instanceVariableNames: 'counter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAPathFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/10/2007 21:38'!
children
	^Array with: counter! !

!WAPathFunctionalTest methodsFor: 'initialize-release' stamp: 'pmm 5/10/2007 21:38'!
initialize
	super initialize.
	counter := WACounter new! !

!WAPathFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/10/2007 21:39'!
renderContentOn: html
	html anchor name: counter count.
	html render: counter! !

!WAPathFunctionalTest methodsFor: 'path' stamp: 'lr 8/30/2008 16:22'!
updateUrl: aUrl 
	super updateUrl: aUrl.
	aUrl addToPath: counter count seasideString.
	aUrl fragment: counter count seasideString! !

WAFunctionalTest subclass: #WAPhraseElementsFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:57'!
renderAbbreviatedOn: html

	html heading level2; with: '<abbr>'.

	html paragraph: [
		html abbreviated
			title: 'World Wide Web';
			with: 'WWW' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:57'!
renderAcronymOn: html

	html heading level2; with: '<acronym>'.

	html paragraph: [
		html acronym
			title: 'Federal Bureau of Investigation';
			with: 'F.B.I.' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/2/2006 21:26'!
renderAddressOn: html

	html heading level2; with: '<address>'.

	html address: [
		#(
			'Newsletter editor'
			'J.R. Brown'
			'JimquickPost News, Jimquick, CT 01234'
			'Tel (123) 456 7890')
			do: [ :each | html text: each ]
			separatedBy: [ html break ] ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:58'!
renderCodeOn: html

	html heading level2; with: '<code>'.

	html paragraph: [
		html text: 'Expressions like '.
		html code: 'a[i++] + b[i++]'.
		html text: ' should not be used, since they cause undefined behavior' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/28/2007 10:46'!
renderContentOn: html
	self renderHarryOn: html.
	self renderAbbreviatedOn: html.
	self renderAcronymOn: html.
	self renderKeyboardInputOn: html.
	self renderVariableOn: html.
	self renderCodeOn: html.
	self renderDefinitionOn: html.
	self renderSampleOn: html.
	self renderAddressOn: html.
	self renderModificationOn: html! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:59'!
renderDefinitionOn: html

	html heading level2; with: '<dfn>'.

	html paragraph: [
		html definition: 'Ichthyology'.
		html text: ' is the branch of natural science which studies fish.' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:56'!
renderHarryOn: html

	html heading level2; with: '<cite>, <q>, <strong>'.

	html paragraph: [
		html text: 'As '.
		html citation: 'Harry S. Truman'.
		html text: ' said, '.
		html quote: 'The buck stops here.'.

		html break.

		html text: 'More information can be found in '.
		html citation: '[ISO-0000]'.
		html text: '.'.

		html break.

		html text: 'Please refer to the following reference number in future correspondence: '.
		html strong: '1-234-55' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:58'!
renderKeyboardInputOn: html

	html heading level2; with: '<kbd>'.

	html paragraph: [
		html text: 'Finally, type '.
		html keyboard: 'logout'.
		html text: ' and press the return key.' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/28/2007 10:48'!
renderModificationOn: html

	html heading level2; with: '<ins>, <del>'.

	html paragraph: [
		html text: 'A Sheriff can employ '.
		html deleted
			title: 'Changed as a result of the SECURE bill.';
			cite: 'http://www.w3.org/TR/html401/struct/text.html#edef-del';
			datetime: '1994-11-05T08:15:30-05:00';
			with: 3.
		html inserted
			title: 'Changed as a result of the SECURE bill.';
			cite: 'http://www.w3.org/TR/html401/struct/text.html#edef-del';
			datetime: '1994-11-05T08:15:30-05:00';
			with: 5.
		html text: ' deputies.' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 15:00'!
renderSampleOn: html

	html heading level2; with: '<samp>'.

	html paragraph: [
		html text: 'If you select the ''champion'' option, you will receive the message '.
		html sample: 'The monkey is not a caterpillar'.
		html text: '.' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:58'!
renderVariableOn: html

	html heading level2; with: '<var>'.

	html paragraph: [
		html text: 'In the simplest case, the command for deleting a file in Unix is'.
		html break.
		html keyboard: 'rm'.
		html space.
		html variable: 'filename' ]! !

WAFunctionalTest subclass: #WAPopupFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAPopupFunctionalTest methodsFor: 'actions' stamp: 'lr 7/4/2007 20:49'!
counterLoop
	WARenderLoop new call: WACounter new! !

!WAPopupFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 14:20'!
renderContentOn: html
	html paragraph: [
		html popupAnchor
			callback: [ self counterLoop ];
			with: 'popup'.
		html break.
		html popupAnchor
			extent: 100 @ 100;
			callback: [ self counterLoop ];
			with: 'popup with extent'.
		html break.
		html popupAnchor
			position: 100 @ 100;
			callback: [ self counterLoop ];
			with: 'popup with position'.
		html break.
		html popupAnchor
			location: true;
			callback: [ self counterLoop ];
			with: 'popup with location'.
		html break.
		html popupAnchor
			resizable: false;
			callback: [ self counterLoop ];
			with: 'popup not resizable' ]! !

WAFunctionalTest subclass: #WARequestFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 11:31'!
renderAcceptCharsetFor: aRequest on: html
	html definitionTerm: 'Accept-Charset:'.
	self renderQualifiedValues: aRequest acceptCharset on: html! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 11:29'!
renderAcceptEncodingFor: aRequest on: html
	html definitionTerm: 'Accept-Encoding:'.
	self renderQualifiedValues: aRequest acceptEncoding on: html! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 11:27'!
renderAcceptFor: aRequest on: html
	html definitionTerm: 'Accept:'.
	self renderQualifiedValues: aRequest accept on: html! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 11:31'!
renderAcceptLanguageFor: aRequest on: html
	html definitionTerm: 'Accept-Language:'.
	self renderQualifiedValues: aRequest acceptLanguage on: html! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 14:21'!
renderContentOn: html
	| request |
	html paragraph: 'This tests whether the server delivers the remote address correctly and headers can be parsed correctly.'.
	request := self requestContext request.
	html definitionList: [
		self renderRemoteAddressFor: request on: html.
		self renderAcceptFor: request on: html.
		self renderAcceptCharsetFor: request on: html.
		self renderAcceptEncodingFor: request on: html.
		self renderAcceptLanguageFor: request on: html ]! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:09'!
renderQualifiedValue: aQualifiedValue on: html
	html listItem: [
		| quality |
		html render: aQualifiedValue value.
		quality := aQualifiedValue quality.
		quality = Float infinity
			ifTrue: [ html superscript: [ html html: '&infin;' ] ]
			ifFalse: [ html superscript: quality ] ]! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 11:35'!
renderQualifiedValues: aCollection on: html
	html definitionData: [
		aCollection isNil
			ifTrue: [ html text: 'N/A' ]
			ifFalse: [
				html orderedList: [
					aCollection do: [ :each |
						self renderQualifiedValue: each on: html ] ] ] ]! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 11:15'!
renderRemoteAddressFor: aRequest on: html
	html definitionTerm: 'Remote Address:'.
	html definitionData: aRequest remoteAddress! !

WAFunctionalTest subclass: #WARubyFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WARubyFunctionalTest commentStamp: 'pmm 9/18/2006 19:11' prior: 0!
Examples taken directly from spec:
http://www.w3.org/TR/2001/REC-ruby-20010531/
!

!WARubyFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/18/2006 22:07'!
renderComplexOn: html
	html heading level2; with: 'Complex ruby markup'.
	html ruby: [
		html rubyBaseContainer: [
			html rubyBase: 10.
			html rubyBase: 31.
			html rubyBase: 2002 ].
		html rubyTextContainer: [
			html rubyText: 'Month'.
			html rubyText: 'Day'.
			html rubyText: 'Year' ].
		html rubyTextContainer: [
			html rubyText
				span: 3;
				with: 'Expiration Date' ] ]! !

!WARubyFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/18/2006 22:06'!
renderContentOn: html
	self renderSimpleOn: html.
	self renderSimpleParenthesesOn: html.
	self renderComplexOn: html! !

!WARubyFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/18/2006 22:07'!
renderSimpleOn: html
	html heading level2; with: 'Simple ruby markup'.
	html ruby: [
		html rubyBase: 'WWW'.
		html rubyText: 'World Wide Web' ]! !

!WARubyFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/18/2006 22:08'!
renderSimpleParenthesesOn: html
	html heading level2; with: 'Simple ruby markup with parentheses'.
	html ruby: [
		html rubyBase: 'WWW'.
		html rubyParentheses: '('.
		html rubyText: 'World Wide Web'.
		html rubyParentheses: ')' ]! !

WAFunctionalTest subclass: #WASvgFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WASvgFunctionalTest methodsFor: 'rendering' stamp: 'jf 9/22/2008 12:15'!
renderContentOn: html
	html object
		type: 'image/svg+xml' seasideMimeType;
		width: 600;
		height: 800;
		standby: 'loading tiger';
		classId: 'http://www.adobe.com/svg/viewer/install/main.html';
		url: 'http://croczilla.com/svg/samples/tiger/tiger.svg';
		with: 'Your browser doesn''t support SVG'! !

WAFunctionalTest subclass: #WATableReportFunctionalTest
	instanceVariableNames: 'report'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WATableReportFunctionalTest class methodsFor: 'accessing' stamp: 'mb 2/10/2006 13:11'!
example

	^ self new! !

!WATableReportFunctionalTest methodsFor: 'accessing' stamp: 'lr 8/6/2007 13:27'!
children
	^ Array with: report! !

!WATableReportFunctionalTest methodsFor: 'initialization' stamp: 'lr 8/6/2007 13:33'!
initialize
	super initialize.
	report := WATableReport new
		rows: WAComponent allSubclasses asArray;
		columns: (OrderedCollection new
			add: (WAReportColumn
				selector: #fullName title: 'Name'
				onClick: [ :each | self inform: each description ]);
			add: ((WAReportColumn
				selector: #canBeRoot title: 'Can Be Root')
				sortBlock: [ :a :b | a ]);
			add: (WAReportColumn
				renderBlock: [ :each :html | html emphasis: each description ]
				title: 'Description');
			yourself);
		rowColors: #(lightblue lightyellow);
		rowPeriod: 1;
		yourself! !

WAFunctionalTest subclass: #WATransactionFunctionalTest
	instanceVariableNames: 'nestedTransation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WATransactionFunctionalTest commentStamp: 'pmm 9/2/2007 00:08' prior: 0!
A WATransactionTest runs a WANestedTransaction with a description!

!WATransactionFunctionalTest methodsFor: 'accessing' stamp: 'pmm 9/2/2007 00:07'!
children
	^Array with: nestedTransation! !

!WATransactionFunctionalTest methodsFor: 'initialize-release' stamp: 'pmm 9/2/2007 00:07'!
initialize
	super initialize.
	nestedTransation := WANestedTransaction new! !

!WATransactionFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/2/2007 00:15'!
renderContentOn: html
	self renderExplanationOn: html.
	html render: nestedTransation! !

!WATransactionFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 14:23'!
renderExplanationOn: html
	html paragraph: 'This checks if nested #isolate: block work. It has the following nested transactions:'.
	html orderedList: [
		html listItem: 'Inside parent txn'.
		html listItem: [
			html orderedList: [
				html listItem: 'Inside child txn' ] ].
		html listItem: 'Outside child txn' ].
	html paragraph: 'If you leave the child transaction and enter it with the back button you should end up in the parent transaction. If you leave the parent transaction with the back button and enter either it or the child transaction with the back button you should end up outside the parent transaction.'! !

WAFunctionalTest subclass: #WATreeFunctionalTest
	instanceVariableNames: 'selected tree'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WATreeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 3/9/2008 11:37'!
children
	^Array with: tree! !

!WATreeFunctionalTest methodsFor: 'initialize-release' stamp: 'pmm 3/9/2008 11:40'!
initialize
	super initialize.
	tree := WATree new
		root: Collection;
		labelBlock: [ :class | class name ];
		childrenBlock: [ :class | class subclasses ];
		selectBlock: [ :class | selected := class name ];
		canSelectBlock: [ :class | class subclasses notEmpty ];
		yourself! !

!WATreeFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/9/2008 11:47'!
renderContentOn: html
	self renderExplanationOn: html.
	self renderTreeOn: html! !

!WATreeFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/9/2008 11:46'!
renderExplanationOn: html
	html paragraph: [
		html text: 'This is a functional test for WATree.'.
		html orderedList: [
			html listItem: 'Clicking on ''+'' should expand a node'.
			html listItem: 'Clicking on ''-'' should collapse a node'.
			html listItem: 'Clicking on a node should display its name after ''Selected:'''.
			html listItem: 'Leaf nodes should not be clickable' ] ]! !

!WATreeFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/9/2008 11:46'!
renderTreeOn: html
	html strong: 'Selected:'.
	html render: selected.
	
	html render: tree! !

!WATreeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 3/9/2008 11:37'!
states
	^Array with: self! !

WAFunctionalTest subclass: #WAUploadFunctionalTest
	instanceVariableNames: 'file'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAUploadFunctionalTest methodsFor: 'rendering' stamp: 'pmm 4/18/2008 07:13'!
renderContentOn: html
	html heading: 'Upload File'.
	self renderUploadOn: html.


	file ifNotNil: [
		self renderDownloadLinksOn: html.
		self renderFileContentsOn: html ]! !

!WAUploadFunctionalTest methodsFor: 'rendering' stamp: 'lr 8/30/2008 16:22'!
renderDownloadLinksOn: html 
	html anchor
		document: file contents
			mimeType: file contentType
			fileName: file fileName;
		with: file fileName , ' (' , file contentType seasideString , ')'.
	html break.
	html anchor
		document: file contents;
		with: file fileName! !

!WAUploadFunctionalTest methodsFor: 'rendering' stamp: 'pmm 8/31/2008 14:50'!
renderFileContentsOn: html 
	file size <= 65536 
		ifTrue: [ html preformatted: file contents ]
		ifFalse: [
			html break.
			html text: 'file size is: ', file size seasideString, ' bytes' ]! !

!WAUploadFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 10:14'!
renderUploadOn: html

	html form
		multipart;
		with: [
			html div: [
				"div for HTML validation"
				html fileUpload callback: [ :f | file := f ].
				html submitButton text: 'Load' ] ]! !

WAFunctionalTest subclass: #WAUrlEncodingFunctionalTest
	instanceVariableNames: 'input'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAUrlEncodingFunctionalTest methodsFor: 'initialize-release' stamp: 'pmm 5/12/2008 09:38'!
initialize
	super initialize.
	input := 'input'! !

!WAUrlEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/11/2008 13:02'!
input
	^input! !

!WAUrlEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/12/2008 09:36'!
input: aString
	input := aString! !

!WAUrlEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 9/28/2008 20:40'!
parameter
	| fieldValue request urlValue |
	request := self requestContext request.
	fieldValue := request at: 'input' ifAbsent: [ nil ].
	urlValue := request url parameters at: 'input' ifAbsent: [ nil ].
	^(fieldValue = urlValue and: [ fieldValue = input ])
		ifTrue: [ fieldValue ]
		ifFalse: [ 'fail!!' ]! !

!WAUrlEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 9/28/2008 20:40'!
path
	| path |
	path := self requestContext request url path last.
	^path = input
		ifTrue: [ path ]
		ifFalse: [ 'fail!!' ]! !

!WAUrlEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/28/2008 20:35'!
renderContentOn: html
	self renderExplanationOn: html.

	html form
		get;
		with: [
			html div: [
				html textInput
					on: #input of: self.
				html submitButton ]].
		
	html definitionList: [
		html definitionTerm: 'Input'.
		html definitionData: self input.
		
		html definitionTerm: 'Parameter'.
		html definitionData: self parameter.
		
		html definitionTerm: 'Path'.
		html definitionData: self path ]! !

!WAUrlEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 09:48'!
renderExplanationOn: html
	html paragraph: 'This tests whether url encoding works.'.
	html unorderedList: [
		html listItem: [
			html text: 'Go to the '.
			html anchor
				url: 'http://www.columbia.edu/kermit/utf8.html';
				with: 'UTF-8 Sampler'.
			html text: ' and select some "foreign" text.' ].
		html listItem: 'Copy and paste it into the urlencoded text field below and click the submit button.'.
		html listItem: 'The text should be displayed below "Input", "Parameter" and "Path" without any error.'.
		html listItem: 'The text may appear in the address bar of the browser.'.
		html listItem: 'Repeat this process for the multipart field. Make sure to pick at least every of these languages: German, Czech, Korean.' ]! !

!WAUrlEncodingFunctionalTest methodsFor: 'updating' stamp: 'lr 5/31/2008 18:29'!
updateUrl: aUrl
	super updateUrl: aUrl.
	input isEmptyOrNil ifTrue: [ ^ self ].
	aUrl addToPath: input.
	aUrl addParameter: 'input' value: input! !

WAComponent subclass: #WAInputElementContainer
	instanceVariableNames: 'textInput textInputExample textArea textAreaExample singleSelection singleSelectionOptional multiSelection nestedSelection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAInputElementContainer methodsFor: 'accessing' stamp: 'pmm 9/19/2007 06:48'!
elements
	^ #( Quito Dakar Sydney Bamako )! !

!WAInputElementContainer methodsFor: 'accessing' stamp: 'pmm 9/19/2007 06:48'!
exampleText
	^ 'Example Text'! !

!WAInputElementContainer methodsFor: 'initialization' stamp: 'pmm 9/19/2007 06:48'!
initialize
	super initialize.
	textInput := textArea := 'Some Text'! !

!WAInputElementContainer methodsFor: 'accessing' stamp: 'pmm 9/19/2007 06:48'!
nestedElements
	^ #(('Functional' ('Haskell ' 'Lisp' 'ML')) ('Dataflow' ('Hartmann pipelines' 'G' 'Max' 'Prograph')) ('Fourth-generation' ('Today' 'Ubercode' 'Uniface')))! !

!WAInputElementContainer methodsFor: 'rendering' stamp: 'pmm 9/19/2007 06:48'!
renderContentOn: html
	self renderHeadingOn: html.
	self renderTextInputOn: html.
	self renderTextInputExampleOn: html.
	self renderTextAreaOn: html.
	self renderTextAreaExampleOn: html.
	self renderSingleSelectionOn: html.
	self renderSingleSelectionOptionalOn: html.
	self renderSingleSelectionWithoutCallbackOn: html.
	self renderMultiSelectionOn: html.
	self renderNestedSelectionOn: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'pmm 9/19/2007 06:48'!
renderHeadingOn: html
	html tableRow: [
		html tableData.
		html tableHeading: 'Control'.
		html tableHeading: 'Print String' ]! !

!WAInputElementContainer methodsFor: 'rendering' stamp: 'pmm 9/19/2007 06:48'!
renderLabel: aString input: anInputBlock output: anOutputBlock on: html
	html tableRow: [
		html tableHeading: aString.
		html tableData: anInputBlock.
		html tableData: anOutputBlock ]! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'pmm 5/12/2008 09:53'!
renderMultiSelectionOn: html
	self
		renderLabel: 'Multi Selection'
		input: [
			html multiSelect
				list: self elements;
				selected: multiSelection;
				callback: [ :value | multiSelection := value ] ]
		output: [
			multiSelection isEmptyOrNil ifFalse: [
				"empty lists are invalid HTML"
				html unorderedList list: multiSelection ] ]
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'lr 10/28/2007 14:42'!
renderNestedSelectionOn: html
	self
		renderLabel: 'Nested Selection'
		input: [
			html select: [
				self nestedElements do: [ :list |
					html optionGroup label: list first; with: [
						list second do: [ :each |
							html option
								selected: nestedSelection = each;
								callback: [ nestedSelection := each ];
								with: each ] ] ] ] ]
		output: nestedSelection printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'lr 10/28/2007 14:42'!
renderSingleSelectionOn: html
	self
		renderLabel: 'Single Selection'
		input: [
			html select
				list: self elements;
				selected: singleSelection;
				callback: [ :value | singleSelection := value ] ]
		output: singleSelection printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'lr 10/28/2007 14:42'!
renderSingleSelectionOptionalOn: html
	self
		renderLabel: 'Single Selection (Optional)'
		input: [
			html select
				beOptional;
				list: self elements;
				optionalLabel: '(none)';
				selected: singleSelectionOptional;
				callback: [ :value | singleSelectionOptional := value ] ]
		output: singleSelectionOptional printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'lr 10/28/2007 14:42'!
renderSingleSelectionWithoutCallbackOn: html
	self
		renderLabel: 'Single Selection (Without Callback)'
		input: [ html select list: self elements ]
		output: nil
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'pmm 9/4/2008 14:53'!
renderTextAreaExampleOn: html
	self
		renderLabel: 'Text Area (Example)'
		input: [
			html textArea
				columns: 17;
				rows: 3;
				value: textAreaExample;
				exampleText: self exampleText;
				callback: [ :value | textAreaExample := value ] ]
		output: textAreaExample printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'pmm 9/4/2008 14:52'!
renderTextAreaOn: html
	self
		renderLabel: 'Text Area'
		input: [
			html textArea
				columns: 17;
				rows: 3;
				value: textArea;
				callback: [ :value | textArea := value ] ]
		output: textArea printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'lr 10/28/2007 14:42'!
renderTextInputExampleOn: html
	self
		renderLabel: 'Text Input (Example)'
		input: [
			html textInput
				value: textInputExample;
				exampleText: self exampleText;
				callback: [ :value | textInputExample := value ] ]
		output: textInputExample printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'lr 10/28/2007 14:42'!
renderTextInputOn: html
	self
		renderLabel: 'Text Input'
		input: [
			html textInput
				setFocus;
				value: textInput;
				callback: [ :value | textInput := value ] ]
		output: textInput printString
		on: html! !

WASession subclass: #WAExpirySession
	instanceVariableNames: ''
	classVariableNames: 'Created Unregistered'
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAExpirySession class methodsFor: 'accessing' stamp: 'avi 9/30/2004 16:30'!
created
	^ Created! !

!WAExpirySession class methodsFor: 'class initialization' stamp: 'avi 9/30/2004 16:24'!
initialize
	self resetCounters! !

!WAExpirySession class methodsFor: 'actions' stamp: 'lr 10/28/2007 14:42'!
resetCounters
	Unregistered := 0.
	Created := 0! !

!WAExpirySession class methodsFor: 'accessing' stamp: 'avi 9/30/2004 16:30'!
unregistered
	^ Unregistered! !

!WAExpirySession methodsFor: 'initialize-release' stamp: 'avi 9/30/2004 16:24'!
initialize
	super initialize.
	Created := Created + 1! !

!WAExpirySession methodsFor: 'subclass responsibilities' stamp: 'lr 2/12/2007 19:37'!
unregistered
	super unregistered.
	Unregistered := Unregistered + 1! !

WATask subclass: #WADecorationTask
	instanceVariableNames: 'component1 component2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WADecorationTask methodsFor: 'running' stamp: 'lr 5/31/2008 10:36'!
go
	self call: component1.
	self call: component2! !

!WADecorationTask methodsFor: 'initialize-release' stamp: 'lr 5/31/2008 15:53'!
initialize
	super initialize.
	component1 := WAFormDialog new
		addMessage: 'Step 1';
		yourself.
	component2 := WAFormDialog new
		addMessage: 'Step 2';
		yourself! !

!WADecorationTask methodsFor: 'initialize-release' stamp: 'lr 5/31/2008 17:46'!
updateStates: aSnapshot
	super updateStates: aSnapshot.
	component1 visiblePresentersDo: [ :each | each updateStates: aSnapshot ].
	component2 visiblePresentersDo: [ :each | each updateStates: aSnapshot ]! !

WATask subclass: #WAFunctionalTaskTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

WAFunctionalTaskTest subclass: #WAConvenienceFunctionalTest
	instanceVariableNames: 'cheese'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAConvenienceFunctionalTest methodsFor: 'controlling' stamp: 'lr 10/28/2007 14:42'!
chooseCheese
	cheese := self
		chooseFrom: #('Greyerzer' 'Tilsiter' 'Sbrinz')
		caption: 'What''s your favorite Cheese?'.
	cheese isNil ifTrue: [ self chooseCheese ]! !

!WAConvenienceFunctionalTest methodsFor: 'controlling' stamp: 'lr 10/28/2007 14:42'!
confirmCheese
	^self confirm: 'Is ', cheese,  ' your favorite cheese?'! !

!WAConvenienceFunctionalTest methodsFor: 'controlling' stamp: 'pmm 6/30/2007 12:24'!
go
	[ self chooseCheese.
	  self confirmCheese ] whileFalse.
	self informCheese! !

!WAConvenienceFunctionalTest methodsFor: 'controlling' stamp: 'lr 10/28/2007 14:42'!
informCheese
	self inform: 'Your favorite cheese is ', cheese, '.'! !

!WAConvenienceFunctionalTest methodsFor: 'accessing' stamp: 'pmm 8/29/2008 16:05'!
states
	^Array with: self! !

WAFunctionalTaskTest subclass: #WAExceptionFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAExceptionFunctionalTest methodsFor: 'processing' stamp: 'pmm 11/1/2007 21:32'!
go
	[ (self confirm: 'Raise an exception?')
		ifTrue: [ self error: 'foo' ] ]
			on: Error
			do: [ :error | self inform: 'Caught: ', error description ]! !

WATask subclass: #WANestedTransaction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WANestedTransaction commentStamp: 'pmm 9/2/2007 00:08' prior: 0!
A WANestedTransaction is a test that uses two nested #isolate: blocks!

!WANestedTransaction methodsFor: 'processing' stamp: 'lr 10/28/2007 14:42'!
go
	self inform: 'Before parent txn'.
	self isolate:
			[self inform: 'Inside parent txn'.
			self isolate: [self inform: 'Inside child txn'].
			self inform: 'Outside child txn'].
	self inform: 'Outside parent txn'! !
WAAllTests initialize!
WADateSelectorFunctionalTest initialize!
WAExpirySession initialize!
